@@ -4,7 +4,7 @@ Main interface for sso service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_sso import (
         Client,
         ListAccountRolesPaginator,
@@ -12,17 +12,15 @@ Usage::
         SSOClient,
     )
 
-    session = boto3.Session()
-
-    client: SSOClient = boto3.client("sso")
-    session_client: SSOClient = session.client("sso")
+    session = Session()
+    client: SSOClient = session.client("sso")
 
     list_account_roles_paginator: ListAccountRolesPaginator = client.get_paginator("list_account_roles")
     list_accounts_paginator: ListAccountsPaginator = client.get_paginator("list_accounts")
     ```
 """
-from mypy_boto3_sso.client import SSOClient
-from mypy_boto3_sso.paginator import ListAccountRolesPaginator, ListAccountsPaginator
+from .client import SSOClient
+from .paginator import ListAccountRolesPaginator, ListAccountsPaginator
 
 Client = SSOClient
 
