@@ -1,7 +1,7 @@
 """
 Type annotations for sso service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso/type_defs/)
 
 Usage::
 
@@ -22,17 +22,20 @@ else:
 
 __all__ = (
     "AccountInfoTypeDef",
-    "GetRoleCredentialsRequestRequestTypeDef",
-    "GetRoleCredentialsResponseTypeDef",
-    "ListAccountRolesRequestRequestTypeDef",
-    "ListAccountRolesResponseTypeDef",
-    "ListAccountsRequestRequestTypeDef",
-    "ListAccountsResponseTypeDef",
-    "LogoutRequestRequestTypeDef",
-    "PaginatorConfigTypeDef",
     "ResponseMetadataTypeDef",
+    "GetRoleCredentialsRequestRequestTypeDef",
     "RoleCredentialsTypeDef",
+    "PaginatorConfigTypeDef",
+    "ListAccountRolesRequestRequestTypeDef",
     "RoleInfoTypeDef",
+    "ListAccountsRequestRequestTypeDef",
+    "LogoutRequestRequestTypeDef",
+    "EmptyResponseMetadataTypeDef",
+    "ListAccountsResponseTypeDef",
+    "GetRoleCredentialsResponseTypeDef",
+    "ListAccountRolesRequestListAccountRolesPaginateTypeDef",
+    "ListAccountsRequestListAccountsPaginateTypeDef",
+    "ListAccountRolesResponseTypeDef",
 )
 
 AccountInfoTypeDef = TypedDict(
@@ -45,6 +48,17 @@ AccountInfoTypeDef = TypedDict(
     total=False,
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
+    },
+)
+
 GetRoleCredentialsRequestRequestTypeDef = TypedDict(
     "GetRoleCredentialsRequestRequestTypeDef",
     {
@@ -54,12 +68,25 @@ GetRoleCredentialsRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetRoleCredentialsResponseTypeDef = TypedDict(
-    "GetRoleCredentialsResponseTypeDef",
+RoleCredentialsTypeDef = TypedDict(
+    "RoleCredentialsTypeDef",
     {
-        "roleCredentials": "RoleCredentialsTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "accessKeyId": str,
+        "secretAccessKey": str,
+        "sessionToken": str,
+        "expiration": int,
     },
+    total=False,
+)
+
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
+    {
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
+    },
+    total=False,
 )
 
 _RequiredListAccountRolesRequestRequestTypeDef = TypedDict(
@@ -85,13 +112,13 @@ class ListAccountRolesRequestRequestTypeDef(
     pass
 
 
-ListAccountRolesResponseTypeDef = TypedDict(
-    "ListAccountRolesResponseTypeDef",
+RoleInfoTypeDef = TypedDict(
+    "RoleInfoTypeDef",
     {
-        "nextToken": str,
-        "roleList": List["RoleInfoTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "roleName": str,
+        "accountId": str,
     },
+    total=False,
 )
 
 _RequiredListAccountsRequestRequestTypeDef = TypedDict(
@@ -116,15 +143,6 @@ class ListAccountsRequestRequestTypeDef(
     pass
 
 
-ListAccountsResponseTypeDef = TypedDict(
-    "ListAccountsResponseTypeDef",
-    {
-        "nextToken": str,
-        "accountList": List["AccountInfoTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 LogoutRequestRequestTypeDef = TypedDict(
     "LogoutRequestRequestTypeDef",
     {
@@ -132,43 +150,80 @@ LogoutRequestRequestTypeDef = TypedDict(
     },
 )
 
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef",
+EmptyResponseMetadataTypeDef = TypedDict(
+    "EmptyResponseMetadataTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
-    },
-    total=False,
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
-RoleCredentialsTypeDef = TypedDict(
-    "RoleCredentialsTypeDef",
+ListAccountsResponseTypeDef = TypedDict(
+    "ListAccountsResponseTypeDef",
     {
-        "accessKeyId": str,
-        "secretAccessKey": str,
-        "sessionToken": str,
-        "expiration": int,
+        "nextToken": str,
+        "accountList": List[AccountInfoTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
-    total=False,
 )
 
-RoleInfoTypeDef = TypedDict(
-    "RoleInfoTypeDef",
+GetRoleCredentialsResponseTypeDef = TypedDict(
+    "GetRoleCredentialsResponseTypeDef",
     {
-        "roleName": str,
+        "roleCredentials": RoleCredentialsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredListAccountRolesRequestListAccountRolesPaginateTypeDef = TypedDict(
+    "_RequiredListAccountRolesRequestListAccountRolesPaginateTypeDef",
+    {
+        "accessToken": str,
         "accountId": str,
     },
+)
+_OptionalListAccountRolesRequestListAccountRolesPaginateTypeDef = TypedDict(
+    "_OptionalListAccountRolesRequestListAccountRolesPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
     total=False,
 )
+
+
+class ListAccountRolesRequestListAccountRolesPaginateTypeDef(
+    _RequiredListAccountRolesRequestListAccountRolesPaginateTypeDef,
+    _OptionalListAccountRolesRequestListAccountRolesPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListAccountsRequestListAccountsPaginateTypeDef = TypedDict(
+    "_RequiredListAccountsRequestListAccountsPaginateTypeDef",
+    {
+        "accessToken": str,
+    },
+)
+_OptionalListAccountsRequestListAccountsPaginateTypeDef = TypedDict(
+    "_OptionalListAccountsRequestListAccountsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListAccountsRequestListAccountsPaginateTypeDef(
+    _RequiredListAccountsRequestListAccountsPaginateTypeDef,
+    _OptionalListAccountsRequestListAccountsPaginateTypeDef,
+):
+    pass
+
+
+ListAccountRolesResponseTypeDef = TypedDict(
+    "ListAccountRolesResponseTypeDef",
+    {
+        "nextToken": str,
+        "roleList": List[RoleInfoTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
